@@ -1,7 +1,7 @@
 // qtractorMidiThumbView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -91,9 +91,6 @@ private:
 	// Local double-buffering pixmap.
 	QPixmap m_pixmap;
 
-	// Local contents length (in ticks).
-	unsigned long m_iContentsLength;
-
 	// Local playhead positioning.
 	int m_iPlayHeadX;
 
